Changelog
#########

All notable changes to this project will be documented in this file.

The format is based on `Keep a
Changelog <https://keepachangelog.com/en/1.0.0/>`__, and this project
adheres to `Semantic
Versioning <https://semver.org/spec/v2.0.0.html>`__.

Unreleased_
===========

0.2.0_ - 2019-01-27
===================

Added
-----
- Sphinx docs

Changed
-------
- Help dialog replaced with hyperlink to online docs
- Labels now have color icons rather than color backgrounds

0.1.1_ - 2019-01-26
===================

Added
-----
- More descriptive README with features list and screenshot
- this changelog

Fixed
-----
- Fix bug of loading images from the current directory

0.1.0_ - 2019-01-25
===================

Added
-----
- Slider for selecting label dot size
- WASD bindings for navigating frames and bodyparts

0.0.3_ - 2019-01-25
===================
Added
-----
- Main GUI from qt branch of UnicodeAlt255's fork of DeepLabCut

0.0.1 - 2019-01-25
==================

Added
-----
- Hatch init

.. _Unreleased: https://gitlab.com/d_/dlc-gui/compare/v0.2.0...master
.. _0.2.0: https://gitlab.com/d_/dlc-gui/compare/v0.1.1...v0.2.0
.. _0.1.1: https://gitlab.com/d_/dlc-gui/compare/v0.1.0...v0.1.1
.. _0.1.0: https://gitlab.com/d_/dlc-gui/compare/v0.0.3...v0.1.0
.. _0.0.3: https://gitlab.com/d_/dlc-gui/compare/v0.0.1...v0.0.3
